# bai2_to_json
This is a simple package built for two purposes: i) learn to use PyPI to distribute packages, and ii) publish the function within, which converts a bai_2 object to a JSON-serialized object.
## Usage
```
import bai2_to_json

path = '$yourpath'

file_to_json(path)
    # returns a json object
```